@@ -1,6 +1,6 @@
 package Hubot::Adapter::Irc;
 {
-  $Hubot::Adapter::Irc::VERSION = '0.0.9';
+  $Hubot::Adapter::Irc::VERSION = '0.0.10';
 }
 use Moose;
 use namespace::autoclean;
@@ -41,6 +41,10 @@ sub join {
 sub part    { }
 sub kick    { }
 sub command { }
+sub whois {
+    my ($self, $nick) = @_;
+    return $self->irc->nick_ident($nick);
+}
 
 sub parse_msg {
     my ( $self, $irc_msg ) = @_;
@@ -56,6 +60,12 @@ sub send {
       for @strings;
 }
 
+sub whisper {
+    my ( $self, $user, $to, @strings ) = @_;
+    $self->irc->send_srv( 'PRIVMSG', $to->{name}, encode_utf8($_) )
+      for @strings;
+}
+
 sub reply {
     my ( $self, $user, @strings ) = @_;
     @strings = map { $user->{name} . ": $_" } @strings;
