@@ -1,6 +1,6 @@
 package Hubot::Response;
 {
-  $Hubot::Response::VERSION = '0.0.9';
+  $Hubot::Response::VERSION = '0.0.10';
 }
 use Moose;
 use namespace::autoclean;
@@ -25,6 +25,11 @@ sub send {
     $self->robot->adapter->send( $self->message->user, @strings );
 }
 
+sub whisper {
+    my ( $self, $to, @strings ) = @_;
+    $self->robot->adapter->whisper( $self->message->user, $to, @strings );
+}
+
 sub topic {
     my ( $self, @strings ) = @_;
     $self->robot->adapter->topic( $self->message->user, @strings );
